@@ -12,17 +12,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import patterns
-from django.conf.urls import url
+from django.urls import re_path
 
 from openstack_dashboard.dashboards.project.networks.subnets import views
 
 
 SUBNETS = r'^(?P<subnet_id>[^/]+)/%s$'
-VIEW_MOD = 'openstack_dashboard.dashboards.project.networks.subnets.views'
 
-
-urlpatterns = patterns(
-    VIEW_MOD,
-    url(SUBNETS % 'detail', views.DetailView.as_view(), name='detail')
-)
+urlpatterns = [
+    re_path(SUBNETS % 'detail', views.DetailView.as_view(), name='detail'),
+]
